### 'create_overview(list_of_dataset_names)' is a utility function that downloads and processes all available datasets to generate an overview of the number of instances available for each target group from each dataset.

### 'create_overview_dict(df_overview)' is a utility function that turns the dataframe generated by 'create_overview' into a dict.

def create_overview(list_of_dataset_names, hf_token=None):
    
    dict_of_datasets = download_datasets(list_of_dataset_names, hf_token)
    dict_of_processed_datasets = process_datasets(dict_of_datasets)    
    
    df_overview = pd.DataFrame({
        'category': [category for category, target_groups in category_dict.items() for t in target_groups],
        'target': [t for category, target_groups in category_dict.items() for t in target_groups]
    })
    
    for dataset_name in list_of_dataset_names:
        df = dict_of_processed_datasets[dataset_name]
        n_targets = []
        for category, target_groups in category_dict.items():
            for target_group in target_groups:
                n_targets.append(len(df[df['target']==target_group]))
        df_overview[dataset_name] = n_targets
                
    return df_overview

def create_overview_dict(df_overview):
    
    dict_overview = {k: [] for k in df_overview['target']}
    
    for i, row in df_overview.iterrows():
        for i_dataset, n_targets in enumerate(row[2:]):
            if n_targets > 0:
                dict_overview[row.iloc[1]].append((list(df_overview.columns)[i_dataset+2],n_targets))
                
    return dict_overview